@@ -495,9 +495,11 @@ gnome_rr_config_new_current (GnomeRRScreen *screen)
 		output->product = 0;
 		output->serial = 0;
 	    }
-	    
-	    output->display_name = make_display_name (
-		gnome_rr_output_get_name (rr_output), info);
+
+	    if (gnome_rr_output_is_laptop (rr_output))
+		output->display_name = g_strdup (_("Laptop"));
+	    else
+		output->display_name = make_display_name (info);
 		
 	    g_free (info);
 		
@@ -1666,14 +1668,18 @@ crtc_assignment_new (GnomeRRScreen *screen, GnomeOutputInfo **outputs, GError **
     {
 	int width, height;
 	int min_width, max_width, min_height, max_height;
+	int required_pixels, min_pixels, max_pixels;
 
 	get_required_virtual_size (assignment, &width, &height);
 
 	gnome_rr_screen_get_ranges (
 	    screen, &min_width, &max_width, &min_height, &max_height);
-    
-	if (width < min_width || width > max_width ||
-	    height < min_height || height > max_height)
+
+	required_pixels = width * height;
+	min_pixels = min_width * min_height;
+	max_pixels = max_width * max_height;
+
+	if (required_pixels < min_pixels || required_pixels > max_pixels)
 	{
 	    g_set_error (error, GNOME_RR_ERROR, GNOME_RR_ERROR_BOUNDS_ERROR,
 			 /* Translators: the "requested", "minimum", and
