@@ -10,7 +10,9 @@ struct ScreenInfo
     int			min_height;
     int			max_height;
 
+#ifdef HAVE_RANDR
     XRRScreenResources *resources;
+#endif
     
     GnomeRROutput **	outputs;
     GnomeRRCrtc **	crtcs;
@@ -19,6 +21,10 @@ struct ScreenInfo
     GnomeRRScreen *	screen;
 
     GnomeRRMode **	clone_modes;
+
+#ifdef HAVE_RANDR
+    RROutput            primary;
+#endif
 };
 
 struct GnomeRRScreen
@@ -36,6 +42,8 @@ struct GnomeRRScreen
     
     GnomeRRScreenChanged	callback;
     gpointer			data;
+
+    Atom                        connector_type_atom;
 };
 
 #endif
